@@ -1,11 +1,11 @@
 /*
- * This content is released under the MIT License as specified in https://raw.githubusercontent.com/gabime/spdlog/master/LICENSE
+ * This content is released under the MIT License as specified in
+ * https://raw.githubusercontent.com/gabime/spdlog/master/LICENSE
  */
 #include "includes.h"
 #include "spdlog/sinks/stdout_sinks.h"
 #include "spdlog/sinks/stdout_color_sinks.h"
-TEST_CASE("stdout_st", "[stdout]")
-{
+TEST_CASE("stdout_st", "[stdout]") {
     auto l = spdlog::stdout_logger_st("test");
     l->set_pattern("%+");
     l->set_level(spdlog::level::trace);
@@ -13,8 +13,7 @@ TEST_CASE("stdout_st", "[stdout]")
     spdlog::drop_all();
 }
 
-TEST_CASE("stdout_mt", "[stdout]")
-{
+TEST_CASE("stdout_mt", "[stdout]") {
     auto l = spdlog::stdout_logger_mt("test");
     l->set_pattern("%+");
     l->set_level(spdlog::level::debug);
@@ -22,16 +21,14 @@ TEST_CASE("stdout_mt", "[stdout]")
     spdlog::drop_all();
 }
 
-TEST_CASE("stderr_st", "[stderr]")
-{
+TEST_CASE("stderr_st", "[stderr]") {
     auto l = spdlog::stderr_logger_st("test");
     l->set_pattern("%+");
     l->info("Test stderr_st");
     spdlog::drop_all();
 }
 
-TEST_CASE("stderr_mt", "[stderr]")
-{
+TEST_CASE("stderr_mt", "[stderr]") {
     auto l = spdlog::stderr_logger_mt("test");
     l->set_pattern("%+");
     l->info("Test stderr_mt");
@@ -42,16 +39,14 @@ TEST_CASE("stderr_mt", "[stderr]")
 }
 
 // color loggers
-TEST_CASE("stdout_color_st", "[stdout]")
-{
+TEST_CASE("stdout_color_st", "[stdout]") {
     auto l = spdlog::stdout_color_st("test");
     l->set_pattern("%+");
     l->info("Test stdout_color_st");
     spdlog::drop_all();
 }
 
-TEST_CASE("stdout_color_mt", "[stdout]")
-{
+TEST_CASE("stdout_color_mt", "[stdout]") {
     auto l = spdlog::stdout_color_mt("test");
     l->set_pattern("%+");
     l->set_level(spdlog::level::trace);
@@ -59,8 +54,7 @@ TEST_CASE("stdout_color_mt", "[stdout]")
     spdlog::drop_all();
 }
 
-TEST_CASE("stderr_color_st", "[stderr]")
-{
+TEST_CASE("stderr_color_st", "[stderr]") {
     auto l = spdlog::stderr_color_st("test");
     l->set_pattern("%+");
     l->set_level(spdlog::level::debug);
@@ -68,8 +62,7 @@ TEST_CASE("stderr_color_st", "[stderr]")
     spdlog::drop_all();
 }
 
-TEST_CASE("stderr_color_mt", "[stderr]")
-{
+TEST_CASE("stderr_color_mt", "[stderr]") {
     auto l = spdlog::stderr_color_mt("test");
     l->set_pattern("%+");
     l->info("Test stderr_color_mt");
@@ -81,8 +74,7 @@ TEST_CASE("stderr_color_mt", "[stderr]")
 
 #ifdef SPDLOG_WCHAR_TO_UTF8_SUPPORT
 
-TEST_CASE("wchar_api", "[stdout]")
-{
+TEST_CASE("wchar_api", "[stdout]") {
     auto l = spdlog::stdout_logger_st("wchar_logger");
     l->set_pattern("%+");
     l->set_level(spdlog::level::trace);
